"use client"

import ArrowCircleRightRoundedIcon from '@mui/icons-material/ArrowCircleRightRounded';
import SearchIcon from '@mui/icons-material/Search';
import { Container, IconButton, InputAdornment, TextField } from '@mui/material';
import { useState } from 'react';
import { getGames } from '@/lib/igdb';
import { IGame } from '@/types/types';
import Game from './Game';

export default function Search() {
    const [searchText, setSearchText] = useState('');
    const [searchResults, setSearchResults] = useState<IGame[]>([]);

    const handleSearch = (event: React.ChangeEvent<HTMLInputElement>) => {
        const searchText = event.target.value;
        setSearchText(searchText);
    };

    const handleSearchSubmit = async () => {
        // Suche der Games durch eigene Sucheingaben.
        const games = await getGames(); // Funktion um die Games aus Datenbank zu getten
        //Es wird geschaut ob gamename(mit to lower Case), dem suchtext (searchText mit to lower case) entspricht.
        const filteredGames = games.filter(game => game.name.toLowerCase().includes(searchText.toLowerCase()));
        setSearchResults(filteredGames);
    };

    return (
        <Container maxWidth="sm" sx={{ justifyContent: "center", textAlign: "center" }}>
            <TextField
                placeholder="Search"
                variant="outlined"
                size="small"
                value={searchText}
                onChange={handleSearch}
                InputProps={{
                    startAdornment: (
                        <InputAdornment position="start">
                            <SearchIcon />
                        </InputAdornment>
                    ),
                    endAdornment: (
                        <InputAdornment position="end">
                            {/* Gesucht wird erst wenn auf Suche geklickt wird. */}
                            <IconButton edge="end" aria-label="start search" onClick={handleSearchSubmit}>
                                <ArrowCircleRightRoundedIcon />
                            </IconButton>
                        </InputAdornment>
                    ),
                    style: {
                        borderRadius: '999px',
                    },
                }}
            />

            {/* Anzeigen der Suchergebnisse */}
            {searchResults.map(game => (
                <Game key={game.id} id={game.id} name={game.name} cover={game.cover} />
            ))}
        </Container>
    );
}