"use client"

import { useEffect, useState } from "react";
import { getGames } from "@/lib/igdb";
import { IGame } from "@/types/types";
import Game from "./Game";
import { Box, Card, CardContent, FormControl, FormHelperText, MenuItem, Select, SelectChangeEvent, Typography } from "@mui/material";


export default function Sort() {
    const [select, setSelect] = useState<string>('');
    const [games, setGames] = useState<IGame[]>([]);
  
    const handleChange = (event: SelectChangeEvent) => {
      const selectedOption = event.target.value as string;
      setSelect(selectedOption);
  
      if (selectedOption === "name") {
        const sortedGames = [...games].sort((a, b) => a.name.localeCompare(b.name));
        setGames(sortedGames);
      }
    };
  
    // Fetch die games wenn die komponenten geladen sind.
    useEffect(() => {
      fetchGames();
    }, []);
  
    const fetchGames = async () => {
      try {
        const games = await getGames(); // methode um die games zu fetchen
        setGames(games);
      } catch (error) {
        console.error("Error fetching games:", error);
      }
    };
  
    return (
      <Box sx={{ position: 'sticky', top: 0 }}>
        <Card variant="outlined">
          <CardContent>
            <Typography>Filter</Typography>
  
            <FormControl fullWidth>
              <FormHelperText>Sort By</FormHelperText>
              <Select
                value={select}
                onChange={handleChange}
                displayEmpty
                inputProps={{ 'aria-label': 'Without label' }}
              >
                <MenuItem value="">
                  <em>Any</em>
                </MenuItem>
                <MenuItem value="name">Name</MenuItem>
              </Select>
            </FormControl>
          </CardContent>
        </Card>
  
        {/* zeigt sortierte games */}
        {games.map((game) => (
          <Game key={game.id} id={game.id} name={game.name} cover={game.cover} />
        ))}
      </Box>
    )
  }